@@ -129,7 +129,7 @@ plotting_data_type <- function(x) {
   }
   if (is_date(x)) {
     "continuous"
-  } else if (!is.null(attributes(x)) || all(is.character(x))) {
+  } else if (any(is.factor(x), is.character(x), is.logical(x))) {
     "discrete"
   } else {
     "continuous"
