@@ -20,16 +20,19 @@
 #' @param errorbar_height height of the error bars
 #' @param errorbar_linetype line type of the error bars
 #' @param errorbar_size size of the error bars
+#' @param sort \code{"none"} (default) do not sort, \code{"ascending"} sort by increasing coefficient value, or \code{"decending"} sort by decreasing coefficient value
 #' @param ... additional arguments sent to \code{\link[ggplot2]{geom_point}}
 #' @examples
 #' library(broom)
 #' reg <- lm(Sepal.Length ~ Sepal.Width + Petal.Length + Petal.Width, data = iris)
 #' ggcoef(reg)
-#'
-#' d <- as.data.frame(Titanic)
+#' \donttest{d <- as.data.frame(Titanic)
 #' reg2 <- glm(Survived ~ Sex + Age + Class, family = binomial, data = d, weights = d$Freq)
 #' ggcoef(reg2, exponentiate = TRUE)
-#' ggcoef(reg2, exponentiate = TRUE, exclude_intercept = TRUE, errorbar_height = .2, color = "blue")
+#' ggcoef(
+#'   reg2, exponentiate = TRUE, exclude_intercept = TRUE,
+#'   errorbar_height = .2, color = "blue", sort = "ascending"
+#' )}
 #' @export
 ggcoef <- function(
   x,
@@ -47,10 +50,11 @@ ggcoef <- function(
   errorbar_height = 0,
   errorbar_linetype = "solid",
   errorbar_size = .5,
+  sort = c("none", "ascending", "decending"),
   ...
 ) {
   if (!is.data.frame(x)) {
-    require_pkgs("broom")
+    require_namespaces("broom")
     x <- broom::tidy(
       x,
       conf.int = conf.int,
@@ -68,6 +72,18 @@ ggcoef <- function(
     x <- x[x$term != "(Intercept)", ]
   }
 
+  sort <- match.arg(sort)
+  if (sort != "none") {
+    x$term <- as.factor(x$term)
+    if (sort == "ascending") {
+      new_order <- order(x$estimate, decreasing = FALSE)
+    } else {
+      new_order <- order(x$estimate, decreasing = TRUE)
+    }
+    x$term <- as.character(x$term)
+    x$term <- factor(x$term, levels = x$term[new_order])
+  }
+
   p <- ggplot(x, mapping = mapping)
 
   if (vline) {
