@@ -8,7 +8,7 @@ if(getRversion() >= "2.15.1") {
 
 #' ggnetworkmap - Plot a network with ggplot2 suitable for overlay on a ggmap:: map ggplot, or other ggplot
 #'
-#' This is a descendent of the original \code{ggnet} function.  \code{ggnet} added the innovation of plotting the network geographically.
+#' This is a descendant of the original \code{ggnet} function.  \code{ggnet} added the innovation of plotting the network geographically.
 #' However, \code{ggnet} needed to be the first object in the ggplot chain.  \code{ggnetworkmap} does not.  If passed a \code{ggplot} object as its first argument,
 #' such as output from \code{ggmap}, \code{ggnetworkmap} will plot on top of that chart, looking for vertex attributes \code{lon} and \code{lat} as coordinates.
 #' Otherwise, \code{ggnetworkmap} will generate coordinates using the Fruchterman-Reingold algorithm.
@@ -184,7 +184,7 @@ ggnetworkmap <- function (
 
   # -- network functions -------------------------------------------------------
 
-  get_v = get("%v%", envir = as.environment("package:network"))
+  get_v = utils::getFromNamespace("%v%", ns = "network")
 
   # -- network structure -------------------------------------------------------
 
