@@ -235,6 +235,7 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 #' @param showStrips boolean to determine if each plot's strips should be displayed. \code{NULL} will default to the top and right side plots only. \code{TRUE} or \code{FALSE} will turn all strips on or off respectively.
 #' @template ggmatrix-legend-param
 #' @param cardinality_threshold maximum number of levels allowed in a character / factor column.  Set this value to NULL to not check factor columns. Defaults to 15
+#' @template ggmatrix-progress
 #' @param legends deprecated
 #' @export
 #' @examples
@@ -319,8 +320,8 @@ stop_if_high_cardinality <- function(data, columns, threshold) {
 #'
 #' ## Between correlation
 #' loess_with_cor <- function(data, mapping, ..., method = "pearson") {
-#'   x <- eval(mapping$x, data)
-#'   y <- eval(mapping$y, data)
+#'   x <- eval_data_col(data, mapping$x)
+#'   y <- eval_data_col(data, mapping$y)
 #'   cor <- cor(x, y, method = method)
 #'   ggally_smooth_loess(data, mapping, ...) +
 #'     ggplot2::geom_label(
@@ -440,6 +441,7 @@ ggduo <- function(
   showStrips = NULL,
   legend = NULL,
   cardinality_threshold = 15,
+  progress = NULL,
   legends = stop("deprecated")
 ) {
 
@@ -546,6 +548,7 @@ ggduo <- function(
     ylab = ylab,
     data = data_,
     gg = NULL,
+    progress = progress,
     legend = legend
   )
 
@@ -613,6 +616,7 @@ ggduo <- function(
 #' @param showStrips boolean to determine if each plot's strips should be displayed. \code{NULL} will default to the top and right side plots only. \code{TRUE} or \code{FALSE} will turn all strips on or off respectively.
 #' @template ggmatrix-legend-param
 #' @param cardinality_threshold maximum number of levels allowed in a character / factor column.  Set this value to NULL to not check factor columns. Defaults to 15
+#' @template ggmatrix-progress
 #' @param legends deprecated
 #' @keywords hplot
 #' @import ggplot2
@@ -720,6 +724,13 @@ ggduo <- function(
 #' # no warning displayed with user supplied function
 #' pm <- ggpairs(tips, 2:3, lower = list(combo = wrap(ggally_facethist, binwidth = 0.5)))
 #' p_(pm)
+#'
+#' ## Remove panel grid lines from correlation plots
+#' pm <- ggpairs(
+#'   flea, columns = 2:4,
+#'   upper = list(continuous = wrap(ggally_cor, displayGrid = FALSE))
+#' )
+#' p_(pm)
 ggpairs <- function(
   data,
   mapping = NULL,
@@ -739,6 +750,7 @@ ggpairs <- function(
   showStrips = NULL,
   legend = NULL,
   cardinality_threshold = 15,
+  progress = NULL,
   legends = stop("deprecated")
 ){
 
@@ -842,6 +854,7 @@ ggpairs <- function(
     ylab = ylab,
     data = data_,
     gg = NULL,
+    progress = progress,
     legend = legend
   )
 
