@@ -455,7 +455,7 @@ ggparcoord <- function(
   else if (order %in% c("Outlying", "Skewed", "Clumpy", "Sparse", "Striated", "Convex", "Skinny",
     "Stringy", "Monotonic")) {
 
-    require_pkgs("scagnostics")
+    require_namespaces("scagnostics")
     scag <- scagnostics::scagnostics(saveData2)
     data.m$variable <- factor(data.m$variable, levels = scag_order(scag, names(saveData2), order))
   }
@@ -569,7 +569,11 @@ ggparcoord <- function(
 
     xAxisLabels <- levels(data.m$variable)
     # while continuous data, this makes it present like it's discrete
-    p <- p + scale_x_discrete(breaks = seq_along(xAxisLabels), labels = xAxisLabels)
+    p <- p + scale_x_continuous(
+      breaks = seq_along(xAxisLabels),
+      labels = xAxisLabels,
+      minor_breaks = FALSE
+    )
 
   } else {
     if (alphaLinesIsCharacter) {
